# Общие правила

Думай и действуй на английском, отвечай в чате на русском.
mcp.txt - Не читай полностью ищи в нем необходимую информацию, это fastmcp докумнетация на случай если нужно будет что-то уточнить
YaTrackerApi - Подробная документация по api яндекс трекера 
Используй uv